@@ -1,28 +1,37 @@
 import random as r
-userpip = input('Do you use pip or pip3?: ')
+import os
+import io
+try:
+  import pygame
+  import pyfiglet
+  from replit import db
+  import requests
+  import ShdwDB
+except ModuleNotFoundError:
+  userpip = input('Do you use pip or pip3?: ')
 try:
   import pygame
   import pygame.locals as GUI_keys
 except ModuleNotFoundError:
-  __import__('os').system(userpip +  ' install pygame')
+  os.system(userpip +  ' install pygame')
 try:
   import pyfiglet
 except ModuleNotFoundError:
-  __import__('os').system(userpip + ' install pyfiglet')
+  os.system(userpip + ' install pyfiglet')
 try:
   from replit import db
 except ModuleNotFoundError:
-  __import__('os').system(userpip + ' install replit')
+  os.system(userpip + ' install replit')
 try:
   import requests
 except ModuleNotFoundError:
-  __import__('os').system(userpip + ' install requests')
+  os.system(userpip + ' install requests')
 import time
 clock = time
 try:
   import ShdwDB as DB
 except ModuleNotFoundError:
-  __import__('os').system(userpip + ' install ShdwDB')
+  os.system(userpip + ' install ShdwDB')
 #print('Type "view()" to view all the functions.')
 zero = 0
 one = 1
@@ -149,6 +158,17 @@ setattr(GUI_keys, 'K_LETTERS', [k.K_a, k.K_b, k.K_c, k.K_d, k.K_e, k.K_f, k.K_g,
 setattr(GUI_keys, 'K_NUMBERS', [k.K_1, k.K_2, k.K_3, k.K_4, k.K_5, k.K_6, k.K_7, k.K_8, k.K_9, k.K_0])
 del k
 setattr(GUI_keys, 'K_WASD', [GUI_keys.K_w, GUI_keys.K_a, GUI_keys.K_s, GUI_keys.K_d])
+def url_load(url):
+  c = requests.get(url).content
+  c = io.BytesIO(c)
+  return GUI.image.load(c)
+setattr(GUI.image, 'url_load', url_load)
+GUI.__doc__ = 'Shdw\'s GUI system has many attributes of the pygame module(https://pypi.org/project/pygame/) and attributes of its own.'
+GUI_change.__doc__ = GUI_change.__doc__.replace('pygame', 'Shdw GUI').replace('module', 'section')
+GUI_clock.__doc__ = GUI_clock.__doc__.replace('pygame', 'Shdw GUI').replace('module', 'section')
+GUI_events.__doc__ = GUI_events.__doc__.replace('pygame', 'Shdw GUI').replace('module', 'section')
+GUI_keys.__doc__ = GUI_keys.__doc__.replace('PyGame', 'Shdw GUI').replace('module', 'file')
+GUI_out.__doc__ = GUI_out.__doc__.replace('pygame', 'Shdw GUI').replace('module', 'section')
 class GUI_colors:
   red = (255, 0, 0)
   green = (0, 255, 0)
@@ -161,22 +181,26 @@ class GUI_colors:
   black = (0, 0, 0)
   white = (255, 255, 255)
 
-class sublist:
-  def example():
-    print('All of list2\'s elements will be removed from list1.')
 def sublists(list1=[], list2=[]):
   for i in list1:
     for j in list2:
       if i == j:
         list1.remove(i)
-  return sublist
+  return list1
+
+def sublist_example():
+    print('All of list2\'s elements will be removed from list1 then return the new list1.')
+
 
 def requester():
   """
   Do not use. This is only for Shdw.
   """
-  r = requests.get("https://client.shivankchhaya.repl.co/requests", data={'update':'\x1b[0;32mUpdate Alert! Please go to the original repl for update.'})
-  print(r.text)
+  usr = input('Username: ')
+  pwd = input('pwd: ')
+  if usr == 'Shdw' and pwd == 'S-h-d-w-BOOM':
+    r = requests.get("https://client.shivankchhaya.repl.co/requests", data={'update':'\x1b[0;32mUpdate Alert! Please go to the original repl for update.'})
+    print(r.text)
   #u = requests.head('http://192.168.86.38/Users/deepchhaya1/Documents/flask_web_app/flaskr.py')
   #print(u.text)
 
@@ -473,4 +497,4 @@ class funfuncs:
     def bin_rand(fromm, to):
         bina = r.randint(fromm, to)
         print('Random Binary: ' + bin(bina).strip('0b'))
-__import__('os').system('clear')
\ No newline at end of file
+os.system('clear')
\ No newline at end of file
